@@ -45,17 +45,24 @@ def assert_aws_credentials():
 	assert 'AWS_SECRET_ACCESS_KEY' in os.environ, "Missing environment variable AWS_SECRET_ACCESS_KEY"
 
 def prepare_docker():
-	return prepare_docker_image(f"{IMAGE_NAME}:{IMAGE_TAG}", IMAGE_NAME, IMAGE_TAG)
+	# print(f"Checking for the latest updates...", end='')
+	client = prepare_docker_image(f"{IMAGE_NAME}:{IMAGE_TAG}", IMAGE_NAME, IMAGE_TAG)
+	# print('Done')
+	
+	return client
 
 def prepare_docker_image(image, name, tag):
+
 	import docker
 	client = docker.from_env()
 	images = client.images.list(image)
 	if len(images):
 		image = images[0]
 	else:
-		print(f'Unable to find {image} in local storage. Pulling the image...')
+		print(f'Unable to find {image} in local storage. Pulling the image...', end = '')
 		image = client.images.pull(name, tag)
+		print('Done')
+
 	return client
 
 def _docker_run(client, volumes, environment, command):
@@ -150,9 +157,7 @@ class DojoCLI(click.MultiCommand):
 
 			# manager_instance_type = manager_instance_type[len(provider) + 1:]
 
-		print(f"Checking for the latest updates...", end='')
 		client = prepare_docker()
-		print('done')
 
 		dojo = os.environ['KAEN_DOJO'] if 'KAEN_DOJO' in os.environ else None
 		while not dojo or dojo[:1].isalpha() is False:
@@ -217,7 +222,7 @@ class DojoCLI(click.MultiCommand):
 		client = prepare_docker()
 		# volumes = get_volumes(provider)
 
-		_docker_run(prepare_docker(), 
+		_docker_run(client,
 								get_volumes(provider), 
 								{ "KAEN_DOJO": dojo,},
 								f"/bin/bash -c '/opt/kaen/{backend}/{provider}/dojo_activate.sh'")
@@ -428,9 +433,7 @@ class JobCLI(click.MultiCommand):
 
 		backend, provider = get_backend_provider(dojo)
 
-		print(f"Checking for the latest version...", end='')
 		client = prepare_docker()
-		print('done')
 
 		volumes = get_volumes(provider)
 		environment = { "KAEN_DOJO": dojo,
@@ -501,9 +504,7 @@ class JobCLI(click.MultiCommand):
 	def start(job, replicas, detach, port, env):
 		"""Start an existing job using the specified number of worker replicas."""
 
-		print(f"Checking for the latest version...", end='')
 		client = prepare_docker()
-		print('done')
 
 		backend, provider = get_backend_provider(job = job)
 
@@ -671,9 +672,7 @@ class HpoCLI(click.MultiCommand):
 		"""Enable hyperparameter optimization(HPO) for a job using
 		the HPO service packaged in the specified image."""
 
-		print(f"Checking for the latest version...", end='')
 		client = prepare_docker()
-		print('done')
 
 		backend, provider = get_backend_provider(job = job)
 
@@ -711,9 +710,7 @@ class HpoCLI(click.MultiCommand):
 		"""Disable hyperparameter optimization(HPO) for a job.
 		If a job never had HPO enabled, this command succeeds."""
 
-		print(f"Checking for the latest version...", end='')
 		client = prepare_docker()
-		print('done')
 
 		backend, provider = get_backend_provider(job = job)
 
